%define name            ufraw
%define version         0.19.2
%define subrel		1
%define release         %mkrel 5

%define build_cinepaint 0
%{?_with_cinepaint: %global build_cinepaint 1}

%if build_cinepaint
%define cinepaint_dir %(pkg-config --variable=programplugindir cinepaint-gtk)
%endif

Name:           %{name}
Version:        %{version}
Release:        %{release}
Summary:        Graphical tool to convert raw images of digital cameras
Group:          Graphics/Photography
URL:            http://ufraw.sourceforge.net/
Source0:        http://downloads.sourceforge.net/sourceforge/ufraw/%{name}-%{version}.tar.gz
Patch0:		ufraw-0.19.2-lcms2.patch
Patch1:		ufraw-0.19.2-CVE-2013-1438.patch
Patch2:		ufraw-0.19.2-CVE-2015-3885.patch
License:        GPLv2+
BuildRequires:  libgimp-devel >= 2.0 gtk+2-devel libjpeg-devel
BuildRequires:  libtiff-devel zlib-devel lcms2-devel imagemagick
BuildRequires:  libexiv-devel bzip2-devel cfitsio-devel
BuildRequires:  libgomp-devel lensfun-devel
%if %build_cinepaint
BuildRequires:  cinepaint-devel
%endif
BuildRequires:  gtkimageview-devel
Suggests:       ufraw-batch

%description
UFRaw is a utility to read and manipulate raw images from digital cameras.
It can be used by itself or as a Gimp plug-in.
It reads raw images using Dave Coffin's raw conversion utility DCRaw.
And it supports basic color management using Little CMS, allowing
the user to apply color profiles.

Raw images are the data directly read from the CCD of the camera,
without in-camera processing, without lossy JPEG compression, and in
36 or 48 bits color depth (TIFF has 24 bits). Problem of the raw
images is that they are in proprietary, camera-specific formats as
they are exactly what the CCD has captured, and the CCDs on differnt
cameras are very different. It also contains info about the camera
settings.

%package batch
Summary:        Commandline tool to convert raw images of digital cameras
Group:          Graphics/Photography

%description batch
This is the commandline tool for UFRaw meant for converting multiple images
in a batch.

%package gimp
Summary:        Reads the raw image formats of digital cameras into GIMP
Group:          Graphics/Editors and Converters
Requires:       gimp
Conflicts:      dcraw-gimp2.0 rawphoto

%description gimp
A GIMP plug-in which reads and processes raw images from most digital
cameras. The conversion is done by the dcraw software and so all
cameras supported by dcraw are also supported by this plug-in.

In contrary to the original GIMP plug-in of dcraw this one is much
more comfortable, especially because of the life preview image but
also due to more options.

%if %build_cinepaint
%package cinepaint
Summary:        Reads the raw image formats of digital cameras into Cinepaint
Group:          Graphics/Editors and Converters
Requires:       cinepaint

%description cinepaint
A Cinepaint plug-in which reads and processes raw images from most digital
cameras. The conversion is done by the dcraw software and so all
cameras supported by dcraw are also supported by this plug-in.
%endif

%prep
%setup -q
%patch0 -p1 -b .lcms2
%patch1 -p1 -b .CVE-2013-1438
%patch2 -p1 -b .CVE-2015-3885

%build
autoreconf -fi
%configure2_5x --enable-mime
%make

%install
rm -fr %buildroot
%makeinstall_std schemasdir=%{_sysconfdir}/gconf/schemas
%find_lang ufraw

install -d %buildroot%{_datadir}/icons/{large,mini}

convert icons/ufraw.png -resize 32x32 %buildroot%{_iconsdir}/%{name}.png
convert icons/ufraw.png -resize 16x16 %buildroot%{_miconsdir}/%{name}.png
cp icons/ufraw.png %buildroot%{_liconsdir}/%{name}.png

%define schemas ufraw

%preun
%preun_uninstall_gconf_schemas %schemas

%files -f %{name}.lang
%defattr(-,root,root)
%doc README
%_sysconfdir/gconf/schemas/ufraw.schemas
%_bindir/ufraw
%_datadir/applications/ufraw.desktop
%_datadir/pixmaps/*.png
%_iconsdir/*.png
%_liconsdir/*.png
%_miconsdir/*.png
%_mandir/man1/ufraw.*

%files batch
%defattr(-,root,root)
%_bindir/ufraw-batch

%files gimp
%defattr(-,root,root)
%{_libdir}/gimp/2.0/plug-ins/*

%if %build_cinepaint
%files cinepaint
%defattr(-,root,root)
%{cinepaint_dir}/plug-ins/*
%endif


%changelog
* Wed May 13 2015 luigiwalser <luigiwalser> 0.19.2-5.1.mga4
+ Revision: 821970
- adapt patch from dcraw to fix CVE-2015-3885

* Thu Dec 26 2013 luigiwalser <luigiwalser> 0.19.2-5.mga4
+ Revision: 560820
- add patches from fedora to build against lcms2 and fix CVE-2013-1438

* Sat Oct 19 2013 umeabot <umeabot> 0.19.2-4.mga4
+ Revision: 530068
- Mageia 4 Mass Rebuild

* Tue Jul 16 2013 eatdirt <eatdirt> 0.19.2-3.mga4
+ Revision: 454957
- Rebuild for cfitsio 3.350

* Mon Jun 03 2013 tv <tv> 0.19.2-2.mga4
+ Revision: 436310
- rebuild for new libpng

* Sat May 25 2013 shlomif <shlomif> 0.19.2-1.mga4
+ Revision: 427425
- Retab and trailing space
- New version - 0.19.2

* Mon Jan 14 2013 umeabot <umeabot> 0.18-6.mga3
+ Revision: 385009
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Jan 13 2013 alien <alien> 0.18-5.mga3
+ Revision: 373455
- Split off ufraw-batch in it's own subpackage

  + boklm <boklm>
    - Update group: Graphics/Editors -> Graphics/Editors and Converters

* Sat Dec 08 2012 malo <malo> 0.18-4.mga3
+ Revision: 328913
- update RPM group

* Sun Dec 25 2011 fwang <fwang> 0.18-3.mga3
+ Revision: 187375
- rebuild for new libtiff

* Sun Oct 09 2011 fwang <fwang> 0.18-2.mga2
+ Revision: 153436
- rebuild for new exiv2

* Sat Feb 26 2011 pterjan <pterjan> 0.18-1.mga2
+ Revision: 60295
- Drop old stuff
- imported package ufraw

